@@ -7,7 +7,6 @@
 
 #include "alarm.h"
 
-#include "alarmmodel.h"
 #include "settingsmodel.h"
 #include "utilmodel.h"
 
@@ -256,3 +255,5 @@ void Alarm::updateNextRingTime()
     m_nextRingTime = m_interface->nextRingTime();
     Q_EMIT nextRingTimeChanged();
 }
+
+#include "moc_alarm.cpp"
